@@ -24,17 +24,24 @@ from textractor.entities.bbox import BoundingBox
 from textractor.entities.document import Document
 from textractor.entities.key_value import KeyValue
 from textractor.entities.table_cell import TableCell
+from textractor.entities.table_title import TableTitle
+from textractor.entities.table_footer import TableFooter
 from textractor.entities.query import Query
-from textractor.validate.validation import validate_entity_schema
 from textractor.entities.document_entity import DocumentEntity
 from textractor.entities.selection_element import SelectionElement
 from textractor.data.constants import (
+    TABLE_FOOTER,
+    TABLE_TITLE,
+    COLUMN_HEADER,
+    TABLE_SUMMARY,
+    TABLE_SECTION_TITLE,
+    TABLE_STRUCTURED,
+    TABLE_SEMI_STRUCTURED,
     SelectionStatus,
     TextTypes,
+    TableTypes,
     HANDWRITING,
     PRINTED,
-)
-from textractor.data.constants import (
     WORD,
     LINE,
     KEY_VALUE_SET,
@@ -177,7 +184,6 @@ def _create_word_objects(
     word_elements = []
 
     for word_id in word_ids:
-        validate_entity_schema(id_json_map[word_id], entity=WORD)
         word_elements.append(id_json_map[word_id])
 
     text_type = {PRINTED: TextTypes.PRINTED, HANDWRITING: TextTypes.HANDWRITING}
@@ -224,7 +230,6 @@ def _create_line_objects(
 
     for line_id in line_ids:
         if line_id in page.child_ids:
-            validate_entity_schema(id_json_map[line_id], entity=LINE)
             page_lines.append(id_json_map[line_id])
 
     lines = []
@@ -274,8 +279,6 @@ def _create_selection_objects(
     :rtype: Dict[str, SelectionElement]
     """
     checkbox_elements = [id_json_map[selection_id] for selection_id in selection_ids]
-    for checkbox_info in checkbox_elements:
-        validate_entity_schema(checkbox_info, entity=SELECTION_ELEMENT)
 
     status = {
         "SELECTED": SelectionStatus.SELECTED,
@@ -370,7 +373,6 @@ def _create_query_objects(
     page_queries = []
     for query_id in query_ids:
         if query_id in page.child_ids:
-            validate_entity_schema(id_json_map[query_id], entity=QUERY)
             page_queries.append(id_json_map[query_id])
 
     query_result_id_map = {}
@@ -407,7 +409,6 @@ def _create_query_result_objects(
     page_query_results = []
     for query_result_id in query_result_ids:
         if query_result_id in page.child_ids:
-            validate_entity_schema(id_json_map[query_result_id], entity=QueryResult)
             page_query_results.append(id_json_map[query_result_id])
 
     query_results = {}
@@ -416,7 +417,18 @@ def _create_query_result_objects(
             entity_id=block["Id"],
             confidence=block["Confidence"],
             result_bbox=BoundingBox.from_normalized_dict(
-                block["Geometry"]["BoundingBox"], spatial_object=page
+                block.get(
+                    "Geometry",
+                    {
+                        'BoundingBox': {
+                            'Width': 1.0,
+                            'Height': 1.0,
+                            'Left': 0.0,
+                            'Top': 0.0
+                        }
+                    }
+                )["BoundingBox"],
+                spatial_object=page
             ),
             answer=block["Text"],
         )
@@ -437,7 +449,6 @@ def _create_signature_objects(
     page_signatures = []
     for signature_id in signature_ids:
         if signature_id in page.child_ids:
-            validate_entity_schema(id_json_map[signature_id], entity=Signature)
             page_signatures.append(id_json_map[signature_id])
 
     signatures = {}
@@ -485,7 +496,6 @@ def _create_keyvalue_objects(
     page_kv = []
     for kv_id in key_value_ids:
         if kv_id in page.child_ids:
-            validate_entity_schema(id_json_map[kv_id], entity=KEY_VALUE_SET)
             page_kv.append(id_json_map[kv_id])
 
     keys_info = _filter_by_entity(page_kv, entity_type="KEY")
@@ -574,7 +584,6 @@ def _create_table_cell_objects(
     for table in page_tables:
         for cell_id in _get_relationship_ids(table, relationship="CHILD"):
             if id_entity_map[cell_id] == CELL:
-                validate_entity_schema(id_json_map[cell_id], entity=CELL)
                 all_table_cells_info[cell_id] = id_json_map[cell_id]
 
     table_cells = {}
@@ -589,7 +598,11 @@ def _create_table_cell_objects(
             row_span=elem["RowSpan"],
             col_span=elem["ColumnSpan"],
             confidence=elem["Confidence"],
-            is_column_header="COLUMN_HEADER" in elem.get("EntityTypes", [])
+            is_column_header=COLUMN_HEADER in elem.get("EntityTypes", []),
+            is_title=TABLE_TITLE in elem.get("EntityTypes", []),
+            is_footer=TABLE_FOOTER in elem.get("EntityTypes", []),
+            is_summary=TABLE_SUMMARY in elem.get("EntityTypes", []),
+            is_section_title=TABLE_SECTION_TITLE in elem.get("EntityTypes", []),
         )
         table_cells[elem_id].raw_object = elem
 
@@ -629,7 +642,6 @@ def _create_table_objects(
     page_tables = []
     for table_id in table_ids:
         if table_id in page.child_ids:
-            validate_entity_schema(id_json_map[table_id], entity=TABLE)
             page_tables.append(id_json_map[table_id])
 
     tables = {}
@@ -640,6 +652,14 @@ def _create_table_objects(
                 val["Geometry"]["BoundingBox"], spatial_object=page
             ),
         )
+        # Setting table type based on the entity types present in the table
+        if TABLE_STRUCTURED in val.get("EntityTypes", []):
+            tables[val["Id"]].table_type = TableTypes.STRUCTURED
+        elif TABLE_SEMI_STRUCTURED in val.get("EntityTypes", []):
+            tables[val["Id"]].table_type = TableTypes.SEMI_STRUCTURED
+        else:
+            tables[val["Id"]].table_type = TableTypes.UNKNOWN
+        # Setting raw JSON in the resulting object
         tables[val["Id"]].raw_object = val
 
     # Create Table Cells
@@ -696,15 +716,64 @@ def _create_table_objects(
                     table_cells[cid] for cid in child_cells
                 ]  # CHECK IF IDS ARE BETTER THAN INSTANCES
 
+    # Create table title (if exists)
+    for table in page_tables:
+        children = _get_relationship_ids(table, relationship="TABLE_TITLE")
+        for child_id in children:
+            tables[table["Id"]].title = TableTitle(
+                entity_id=child_id,
+                bbox=BoundingBox.from_normalized_dict(
+                    id_json_map[child_id]["Geometry"]["BoundingBox"],
+                    spatial_object=page
+                )
+            )
+            children = _get_relationship_ids(id_json_map[child_id], relationship="CHILD")
+            tables[table["Id"]].title.words = _create_word_objects(
+                [child_id for child_id in children if id_entity_map[child_id] == WORD],
+                id_json_map,
+                page
+            )
+
+    # Create table footer (if exists)
+    for table in page_tables:
+        children = _get_relationship_ids(table, relationship="TABLE_FOOTER")
+        for child_id in children:
+            tables[table["Id"]].footers.append(
+                TableFooter(
+                    entity_id=child_id,
+                    bbox=BoundingBox.from_normalized_dict(
+                        id_json_map[child_id]["Geometry"]["BoundingBox"],
+                        spatial_object=page
+                    )
+                )
+            )
+            children = _get_relationship_ids(id_json_map[child_id], relationship="CHILD")
+            tables[table["Id"]].footers[-1].words = _create_word_objects(
+                [child_id for child_id in children if id_entity_map[child_id] == WORD],
+                id_json_map,
+                page
+            )
+
     # Associate Children with Tables
     for table in page_tables:
         children = _get_relationship_ids(table, relationship="CHILD")
         children_cells = []
         for child_id in children:
             children_cells.append(table_cells[child_id])
+            if table_cells[child_id].is_title:
+                tables[table["Id"]].title.is_floating = False
+        # FIXME: This will be slow and there should be a better way to do it.
+        words = set([w.id for child_id in children for w in table_cells[child_id].words])
+        for footer in tables[table["Id"]].footers:
+            for w in footer.words:
+                if w.id in words:
+                    footer.is_floating = False
+                    break
 
         tables[table["Id"]].add_cells(children_cells)
 
+    
+
     tables = list(tables.values())
     for table in tables:
         table.page = page.page_num
@@ -812,8 +881,13 @@ def create_expense_from_field(field: Dict, page: Page) -> ExpenseField:
         type_expense = None
     if "ValueDetection" in field:
         value_expense = Expense(
-            bbox=BoundingBox.from_normalized_dict(
-                field["ValueDetection"]["Geometry"]["BoundingBox"], spatial_object=page
+            bbox=(
+                None
+                if not "Geometry" in field["ValueDetection"] else 
+                BoundingBox.from_normalized_dict(
+                    field["ValueDetection"]["Geometry"]["BoundingBox"],
+                    spatial_object=page
+                )
             ),
             text=field["ValueDetection"]["Text"],
             confidence=field["ValueDetection"]["Confidence"],
@@ -848,7 +922,6 @@ def create_expense_from_field(field: Dict, page: Page) -> ExpenseField:
                         currency=currency, page=page.page_num)
 
 
-
 def parser_analyze_expense_response(response):
     response["Blocks"] = [b for doc in response["ExpenseDocuments"] for b in doc.get("Blocks", [])]
     document = parse_document_api_response(response)
@@ -871,6 +944,8 @@ def parser_analyze_expense_response(response):
                     row_expenses.append(create_expense_from_field(line_item_field, page))
                     row_expenses[-1].raw_object = line_item_field
                 line_item_rows.append(LineItemRow(index=i, line_item_expense_fields=row_expenses, page=page.page_num))
+            if not line_item_rows:
+                continue
             line_items_groups.append(LineItemGroup(index=line_items_group["LineItemGroupIndex"], line_item_rows=line_item_rows, page=page.page_num))
 
         bbox = BoundingBox.enclosing_bbox(bboxes=[s.bbox for s in summary_fields] + [g.bbox for g in line_items_groups], spatial_object=page)
@@ -897,10 +972,15 @@ def parse(response: dict) -> Document:
     :return: Document object returned after making respective parse function calls.
     :rtype: Document
     """
-
     if "IdentityDocuments" in response:
+        from trp.trp2_analyzeid import TAnalyzeIdDocumentSchema
+        t_doc = TAnalyzeIdDocumentSchema().load(response)
         return parse_analyze_id_response(response)
     if "ExpenseDocuments" in response:
+        from trp.trp2_expense import TAnalyzeExpenseDocumentSchema
+        t_doc = TAnalyzeExpenseDocumentSchema().load(response)
         return parser_analyze_expense_response(response)
     else:
+        from trp.trp2 import TDocumentSchema
+        t_doc = TDocumentSchema().load(response)
         return parse_document_api_response(response)
