@@ -94,7 +94,10 @@ class Textractor:
             raise InputError(
                 "Unable to initiate Textractor. Either profile_name or region requires an input parameter."
             )
-        self.textract_client = self.session.client("textract")
+        if self.region_name is not None:
+            self.textract_client = self.session.client("textract", region_name=self.region_name)
+        else:
+            self.textract_client = self.session.client("textract")
         self.s3_client = self.session.client("s3")
 
     def _get_document_images_from_path(self, filepath: str) -> List[Image.Image]:
@@ -119,7 +122,7 @@ class Textractor:
                 else boto3.session.Session(region_name=self.region_name).client("s3")
             )
             file_obj = s3_client.get_object(Bucket=bucket, Key=key).get("Body").read()
-            if filepath.endswith(".pdf"):
+            if filepath.lower().endswith(".pdf"):
                 if IS_PDF2IMAGE_INSTALLED:
                     images = convert_from_bytes(bytearray(file_obj))
                 else:
@@ -128,7 +131,7 @@ class Textractor:
                 images = [Image.open(io.BytesIO(bytearray(file_obj)))]
 
         else:
-            if filepath.endswith(".pdf"):
+            if filepath.lower().endswith(".pdf"):
                 if IS_PDF2IMAGE_INSTALLED:
                     images = convert_from_path(filepath)
                 else:
@@ -267,7 +270,7 @@ class Textractor:
             )
 
         # If the file is not already in S3
-        if not file_source.startswith("s3://"):
+        if not isinstance(file_source, str) or not file_source.startswith("s3://"):
             # Check if the user has given us a bucket to upload to
             if not s3_upload_path:
                 raise InputError(
@@ -442,7 +445,6 @@ class Textractor:
                 page.image = images[document.pages.index(page)]
         return document
 
-    # FIXME: This should not be synchronous
     def start_document_analysis(
         self,
         file_source: Union[str, bytes, Image.Image],
@@ -456,10 +458,10 @@ class Textractor:
     ) -> LazyDocument:
         """
         Make a call to the ASYNC StartDocumentAnalysis API, implicitly parses the response and produces a :class:`Document` object.
-        This function is ideal for multipage PDFs or list of images.
+        This function is ideal for multipage PDFs or an image.
 
-        :param file_source: Path to a file stored locally, on an S3 bucket or list of PIL Images
-        :type file_source: str or List[PIL.Image], required
+        :param file_source: Path to a file stored locally, on an S3 bucket or a PIL Image
+        :type file_source: Union[str, bytes, Image.Image], required
         :param features: List of TextractFeatures to be extracted from the Document by the TextractAPI
         :type features: list, required
         :param s3_output_path: Path to store the output on the S3 bucket (passed as param to Textractor).
@@ -724,9 +726,9 @@ class Textractor:
         save_image: bool = True,
     ) -> LazyDocument:
         """Make a call to the ASYNC StartExpenseAnalysis API, implicitly parses the response and produces a :class:`Document` object.
-        This function is ideal for multipage PDFs or list of images.
+        This function is ideal for multipage PDFs or an image.
 
-        :param file_source: Path to a file stored locally, on an S3 bucket or list of PIL Images
+        :param file_source: Path to a file stored locally, on an S3 bucket or a PIL Image
         :type file_source: Union[str, bytes, Image.Image]
         :param s3_output_path: Path to store the output on the S3 bucket (passed as param to Textractor).
         :type s3_output_path: str
@@ -761,7 +763,7 @@ class Textractor:
             )
 
         # If the file is not already in S3
-        if not file_source.startswith("s3://"):
+        if not isinstance(file_source, str) or not file_source.startswith("s3://"):
             # Check if the user has given us a bucket to upload to
             if not s3_upload_path:
                 raise InputError(
